@@ -23,17 +23,13 @@ LOG = logging.getLogger(__name__)
 
 
 class HousekeeperAPI:
-    """API to decouple cg code from Housekeeper"""
+    """API to decouple cg code from Housekeeper."""
 
     def __init__(self, config: dict) -> None:
         initialize_database(config["housekeeper"]["database"])
         self._store = Store(config["housekeeper"]["root"])
         self.root_dir: str = config["housekeeper"]["root"]
 
-    def __getattr__(self, name):
-        LOG.warning(f"Called undefined {name} on {self.__class__.__name__}, please wrap")
-        return getattr(self._store, name)
-
     def new_bundle(self, name: str, created_at: datetime = None) -> Bundle:
         """Create a new file bundle."""
         return self._store.new_bundle(name, created_at)
@@ -189,6 +185,21 @@ class HousekeeperAPI:
         files: Query = self._store.get_files(bundle_name=bundle, tag_names=tags, version_id=version)
         return files.order_by(File.id.desc()).first()
 
+    def get_file_by_exact_tags(
+        self, bundle: str, tags: list, version: int | None = None
+    ) -> File | None:
+        """Return a file that matches exact tags and optionally filtered by bundle and version."""
+        if not tags:
+            LOG.debug("No tags provided, skipping")
+            return None
+        files: list[File] = self.files(bundle=bundle, version=version, tags=tags).all()
+        for file in files:
+            file_tags = {tag.name for tag in file.tags}
+            LOG.debug(f"Using tags {file_tags}")
+            if file_tags == set(tags):
+                LOG.debug(f"Found file {file}")
+                return file
+
     def check_bundle_files(
         self,
         bundle_name: str,
@@ -242,12 +253,9 @@ class HousekeeperAPI:
         """Create a new bundle version."""
         return self._store.new_version(created_at, expires_at)
 
-    def version(self, bundle: str, date: datetime) -> Version:
-        """Fetch a version."""
-        LOG.debug(f"Return version: {date}, from {bundle}")
-        return self._store.get_version_by_date_and_bundle_name(
-            bundle_name=bundle, version_date=date
-        )
+    def get_version_by_id(self, version_id: int) -> Version:
+        """Return a version given its database ID."""
+        return self._store.get_version_by_id(version_id=version_id)
 
     def last_version(self, bundle: str) -> Version:
         """Gets the latest version of a bundle."""
@@ -273,7 +281,7 @@ class HousekeeperAPI:
         """Get the latest version of a Housekeeper bundle."""
         last_version: Version = self.last_version(bundle_name)
         if not last_version:
-            LOG.warning(f"No bundle found for {bundle_name} in Housekeeper")
+            LOG.debug(f"No bundle found for {bundle_name} in Housekeeper")
             return None
         LOG.debug(f"Found Housekeeper version object for {bundle_name}: {repr(last_version)}")
         return last_version
