@@ -1,4 +1,4 @@
-import click
+import rich_click as click
 
 from cg.constants.priority import SlurmQos
 
