@@ -1,4 +1,4 @@
-import click
+import rich_click as click
 
 DRY_RUN = click.option(
     "--dry-run",
@@ -29,3 +29,9 @@ COMMENT = click.option(
     required=False,
     help="A comment providing an explanation for the forced action",
 )
+
+LIMIT = click.option(
+    "--limit",
+    type=int,
+    help="Maximum number of cases to start",
+)
