@@ -3,22 +3,18 @@
 from enum import StrEnum
 
 from cg.constants.constants import Workflow
-from cg.constants.housekeeper_tags import (
-    AlignmentFileTag,
-    AnalysisTag,
-    HermesFileTag,
-)
+from cg.constants.housekeeper_tags import AlignmentFileTag, AnalysisTag, HermesFileTag
 
 ONLY_ONE_CASE_PER_TICKET: list[Workflow] = [
-    Workflow.FASTQ,
     Workflow.MICROSALT,
     Workflow.MUTANT,
+    Workflow.RAW_DATA,
 ]
 
 SKIP_MISSING: list[Workflow] = [
-    Workflow.FASTQ,
     Workflow.MICROSALT,
     Workflow.MUTANT,
+    Workflow.RAW_DATA,
 ]
 
 BALSAMIC_ANALYSIS_CASE_TAGS: list[set[str]] = [
@@ -48,16 +44,6 @@ BALSAMIC_ANALYSIS_SAMPLE_TAGS: list[set[str]] = [
     {AlignmentFileTag.CRAM_INDEX},
 ]
 
-BALSAMIC_QC_ANALYSIS_CASE_TAGS: list[set[str]] = [
-    {"delivery-report"},
-    {"multiqc-html"},
-]
-
-BALSAMIC_QC_ANALYSIS_SAMPLE_TAGS: list[set[str]] = [
-    {"qc-cram"},
-    {"qc-cram-index"},
-]
-
 BALSAMIC_UMI_ANALYSIS_CASE_TAGS: list[set[str]] = [
     {"vcf-umi-snv"},
     {"vcf-umi-snv-index"},
@@ -78,10 +64,11 @@ BALSAMIC_UMI_ANALYSIS_SAMPLE_TAGS.extend(BALSAMIC_ANALYSIS_SAMPLE_TAGS)
 
 CLINICAL_DELIVERY_TAGS: list[set[str]] = [{HermesFileTag.CLINICAL_DELIVERY}]
 
-FASTQ_ANALYSIS_CASE_TAGS: list[set[str]] = []
+RAW_DATA_ANALYSIS_CASE_TAGS: list[set[str]] = []
 
-FASTQ_ANALYSIS_SAMPLE_TAGS: list[set[str]] = [
+RAW_DATA_ANALYSIS_SAMPLE_TAGS: list[set[str]] = [
     {"fastq"},
+    {"bam"},
 ]
 
 MIP_DNA_ANALYSIS_CASE_TAGS: list[set[str]] = [
@@ -140,7 +127,7 @@ MIP_RNA_ANALYSIS_SAMPLE_TAGS: list[set[str]] = [
 
 MICROSALT_ANALYSIS_CASE_TAGS = [{"qc-report"}, {"typing-report"}]
 
-MICROSALT_ANALYSIS_SAMPLE_TAGS: list[set[str]] = []
+MICROSALT_ANALYSIS_SAMPLE_TAGS: list[set[str]] = [{"storage", "assembly"}]
 
 MUTANT_ANALYSIS_CASE_TAGS: list[set[str]] = [
     {"pangolin"},
@@ -148,7 +135,6 @@ MUTANT_ANALYSIS_CASE_TAGS: list[set[str]] = [
 ]
 
 MUTANT_ANALYSIS_SAMPLE_TAGS: list[set[str]] = [
-    {"fastq"},
     {"vcf", "vcf-report", "fohm-delivery"},
 ]
 
@@ -158,10 +144,6 @@ PIPELINE_ANALYSIS_TAG_MAP: dict[Workflow, dict] = {
         "case_tags": BALSAMIC_ANALYSIS_CASE_TAGS,
         "sample_tags": BALSAMIC_ANALYSIS_SAMPLE_TAGS,
     },
-    Workflow.BALSAMIC_QC: {
-        "case_tags": BALSAMIC_QC_ANALYSIS_CASE_TAGS,
-        "sample_tags": BALSAMIC_QC_ANALYSIS_SAMPLE_TAGS,
-    },
     Workflow.BALSAMIC_UMI: {
         "case_tags": BALSAMIC_UMI_ANALYSIS_CASE_TAGS,
         "sample_tags": BALSAMIC_UMI_ANALYSIS_SAMPLE_TAGS,
@@ -178,18 +160,22 @@ PIPELINE_ANALYSIS_TAG_MAP: dict[Workflow, dict] = {
         "case_tags": MICROSALT_ANALYSIS_CASE_TAGS,
         "sample_tags": MICROSALT_ANALYSIS_SAMPLE_TAGS,
     },
-    Workflow.FASTQ: {
-        "case_tags": FASTQ_ANALYSIS_CASE_TAGS,
-        "sample_tags": FASTQ_ANALYSIS_SAMPLE_TAGS,
-    },
     Workflow.MUTANT: {
         "case_tags": MUTANT_ANALYSIS_CASE_TAGS,
         "sample_tags": MUTANT_ANALYSIS_SAMPLE_TAGS,
     },
+    Workflow.NALLO: {
+        "case_tags": CLINICAL_DELIVERY_TAGS,
+        "sample_tags": CLINICAL_DELIVERY_TAGS,
+    },
     Workflow.RAREDISEASE: {
         "case_tags": CLINICAL_DELIVERY_TAGS,
         "sample_tags": CLINICAL_DELIVERY_TAGS,
     },
+    Workflow.RAW_DATA: {
+        "case_tags": RAW_DATA_ANALYSIS_CASE_TAGS,
+        "sample_tags": RAW_DATA_ANALYSIS_SAMPLE_TAGS,
+    },
     Workflow.RNAFUSION: {
         "case_tags": CLINICAL_DELIVERY_TAGS,
         "sample_tags": CLINICAL_DELIVERY_TAGS,
@@ -211,6 +197,8 @@ OUTBOX_NAME: str = "outbox"
 
 
 class FileDeliveryOption(StrEnum):
-    FASTQ: str = "fastq"
     ANALYSIS: str = "analysis"
+    BAM: str = "bam"
+    FASTQ: str = "fastq"
     FASTQ_ANALYSIS: str = "fastq-analysis"
+    RAW_DATA_ANALYSIS: str = "raw_data-analysis"
