@@ -15,13 +15,32 @@ class NfTowerStatus(StrEnum):
     UNKNOWN: str = "UNKNOWN"
 
 
-RAREDISEASE_METRIC_CONDITIONS: dict[str, dict[str, Any]] = {
-    "percent_duplicates": {"norm": "lt", "threshold": 20},
+NALLO_METRIC_CONDITIONS: dict[str, dict[str, Any]] = {
+    "median_coverage": {"norm": "gt", "threshold": 20},
+    "predicted_sex_sex_check": {"norm": "eq", "threshold": None},
+}
+
+RAREDISEASE_PREDICTED_SEX_METRIC = "predicted_sex_sex_check"
+
+RAREDISEASE_METRIC_CONDITIONS_WES: dict[str, dict[str, Any]] = {
+    "PERCENT_DUPLICATION": {"norm": "lt", "threshold": 0.20},
+    "PCT_PF_UQ_READS_ALIGNED": {"norm": "gt", "threshold": 0.95},
+    "PCT_TARGET_BASES_10X": {"norm": "gt", "threshold": 0.95},
+    "AT_DROPOUT": {"norm": "lt", "threshold": 10},
+    "GC_DROPOUT": {"norm": "lt", "threshold": 10},
+    RAREDISEASE_PREDICTED_SEX_METRIC: {"norm": "eq", "threshold": None},
+    "gender": {"norm": "eq", "threshold": None},
+}
+
+RAREDISEASE_METRIC_CONDITIONS_WGS: dict[str, dict[str, Any]] = {
+    "PERCENT_DUPLICATION": {"norm": "lt", "threshold": 0.20},
     "PCT_PF_UQ_READS_ALIGNED": {"norm": "gt", "threshold": 0.95},
     "MEDIAN_TARGET_COVERAGE": {"norm": "gt", "threshold": 25},
     "PCT_TARGET_BASES_10X": {"norm": "gt", "threshold": 0.95},
-    "PCT_EXC_ADAPTER": {"norm": "lt", "threshold": 0.0005},
-    "predicted_sex_sex_check": {"norm": "eq", "threshold": None},
+    "AT_DROPOUT": {"norm": "lt", "threshold": 5},
+    "GC_DROPOUT": {"norm": "lt", "threshold": 5},
+    RAREDISEASE_PREDICTED_SEX_METRIC: {"norm": "eq", "threshold": None},
+    "gender": {"norm": "eq", "threshold": None},
 }
 
 RAREDISEASE_PARENT_PEDDY_METRIC_CONDITION: dict[str, dict[str, Any]] = {
@@ -45,14 +64,18 @@ TOMTE_METRIC_CONDITIONS: dict[str, dict[str, Any]] = {
 
 MULTIQC_NEXFLOW_CONFIG = """process {
     withName:'MULTIQC' {
-        memory = { 1.GB * task.attempt }
+        memory = { 4.GB * task.attempt }
         time   = { 4.h  * task.attempt }
         cpus = 2
-        ext.args = ' --data-format json '
+        ext.args = ' --data-format json --cl-config "max_table_rows: 10000" '
     }
 }
 """
 
+NALLO_COVERAGE_FILE_TAGS: list[str] = ["d4"]
+NALLO_COVERAGE_INTERVAL_TYPE: str = "genes"
+NALLO_COVERAGE_THRESHOLD: int = 10
+
 RAREDISEASE_COVERAGE_FILE_TAGS: list[str] = ["coverage", "d4"]
 RAREDISEASE_COVERAGE_INTERVAL_TYPE: str = "genes"
 RAREDISEASE_COVERAGE_THRESHOLD: int = 10
