@@ -12,6 +12,12 @@ class CgError(Exception):
         super().__init__(message)
 
 
+class AnalysisDoesNotExistError(CgError):
+    """
+    Exception raised when an analysis does not exist.
+    """
+
+
 class AnalysisUploadError(CgError):
     """
     Error related to trying to upload analysis data.
@@ -36,6 +42,18 @@ class AnalysisNotCompletedError(CgError):
     """
 
 
+class AnalysisAlreadyStoredError(CgError):
+    """
+    Exception raised when trying to store an analysis already stored in StatusDB.
+    """
+
+
+class AnalysisRunningError(CgError):
+    """
+    Exception raised when trying to start a case which is running in Trailblazer.
+    """
+
+
 class BalsamicStartError(CgError):
     """
     Exception raised when Balsamic fails to start.
@@ -86,6 +104,10 @@ class DecompressionNeededError(CgError):
     """Raised when decompression still needed to start analysis."""
 
 
+class DecompressionCouldNotStartError(CgError):
+    """Raised when decompression could not be started."""
+
+
 class DeliveryReportError(CgError):
     """
     Exception related to delivery report creation.
@@ -104,6 +126,10 @@ class FlowCellError(CgError):
     """Raised when there is a problem with a flow cell."""
 
 
+class AuthorisationError(CgError):
+    """Raised when a forbidden transaction is attempted by an external user."""
+
+
 class IlluminaRunsNeededError(CgError):
     """Raised when fetching flow cells still needed to start analysis."""
 
@@ -174,6 +200,12 @@ class OrderError(CgError):
     """
 
 
+class OrderSubmissionError(CgError):
+    """
+    Exception related to order submission.
+    """
+
+
 class OrderFormError(CgError):
     """
     Exception related to the order form.
@@ -298,10 +330,6 @@ class OrderNotFoundError(CgError):
     """Exception raised when an order is not found."""
 
 
-class OrderExistsError(CgError):
-    """Exception raised when cases and samples are added to a pre-existing order."""
-
-
 class OrderMismatchError(CgError):
     """Exception raised when cases expected to belong to the same order are not part of the same order."""
 
@@ -328,3 +356,7 @@ class Chanjo2RequestError(Chanjo2APIClientError):
 
 class Chanjo2ResponseError(Chanjo2APIClientError):
     """Exception raised when the response from Chanjo2 API client fails validation."""
+
+
+class CaseNotConfiguredError(CgError):
+    """Exception raised when a case is being run without a configuration."""
