@@ -1,11 +1,11 @@
 import logging
 from enum import Enum
-from typing import Dict, Union, List
 
-from cg.store.models import Pool, Sample
 import genologics.entities
+
 from cg.apps.lims import LimsAPI
-from cg.store import Store
+from cg.store.models import Pool, Sample
+from cg.store.store import Store
 
 LOG = logging.getLogger(__name__)
 
@@ -57,9 +57,9 @@ class TransferLims(object):
         """Transfer information about samples."""
 
         if sample_id:
-            samples: List[Sample] = self.status.get_samples_by_internal_id(internal_id=sample_id)
+            samples: list[Sample] = self.status.get_samples_by_internal_id(internal_id=sample_id)
         else:
-            samples: List[Sample] = self._get_samples_to_include(include, status_type)
+            samples: list[Sample] = self._get_samples_to_include(include, status_type)
 
         if samples is None:
             LOG.info(f"No samples to process found with {include} {status_type.value}")
@@ -104,7 +104,7 @@ class TransferLims(object):
             if not self._is_pool_valid(pool_obj, ticket, number_of_samples):
                 continue
 
-            samples_in_pool: Union[Dict[str:str], List[genologics.Sample]] = self.lims.get_samples(
+            samples_in_pool: dict[str, str] | list[genologics.Sample] = self.lims.get_samples(
                 projectname=ticket
             )
             for sample_obj in samples_in_pool:
@@ -114,17 +114,12 @@ class TransferLims(object):
                 if status_date is None:
                     continue
 
-                LOG.info(
-                    "Found %s date for pool id %s: %s",
-                    status_type.value,
-                    pool_obj.id,
-                    status_date,
-                )
+                LOG.info(f"Found {status_type.value} date for pool id {pool_obj.id}: {status_date}")
                 setattr(pool_obj, f"{status_type.value}_at", status_date)
                 self.status.session.commit()
                 break
 
-    def _get_samples_in_step(self, status_type) -> List[Sample]:
+    def _get_samples_in_step(self, status_type) -> list[Sample]:
         return self._sample_functions[status_type]()
 
     @staticmethod
@@ -145,19 +140,14 @@ class TransferLims(object):
         name of the pool object it's part of"""
         if sample_obj.udf.get("pool name") is None:
             LOG.warning(
-                "No pool name found for sample %s (sample name %s, project %s)",
-                sample_obj.id,
-                sample_obj.name,
-                sample_obj.project.name,
+                f"No pool name found for sample {sample_obj} (sample name {sample_obj.name}, project {sample_obj.project.name})"
             )
             return False
 
         sample_pool_name = sample_obj.udf["pool name"]
         if sample_pool_name != pool_obj.name:
             LOG.warning(
-                "The udf 'pool name' of the sample (%s) does not match the name of the pool (%s))",
-                sample_pool_name,
-                pool_obj.name,
+                f"The udf 'pool name' of the sample ({sample_pool_name}) does not match the name of the pool ({pool_obj.name}))"
             )
             return False
         return True
