@@ -1,7 +1,6 @@
 import logging
 
-import click
-
+import rich_click as click
 
 from cg.meta.upload.upload_api import UploadAPI
 from cg.meta.workflow.microsalt.microsalt import MicrosaltAnalysisAPI
@@ -18,7 +17,7 @@ class MicrosaltUploadAPI(UploadAPI):
 
     def upload(self, ctx: click.Context, case: Case, restart: bool) -> None:
         """Uploads MicroSALT analysis data and files."""
-        analysis: Analysis = case.analyses[0]
+        analysis: Analysis = self.status_db.get_latest_completed_analysis_for_case(case.internal_id)
         self.update_upload_started_at(analysis)
 
         self.upload_files_to_customer_inbox(case)
