@@ -6,14 +6,15 @@ from pathlib import Path
 from subprocess import CalledProcessError
 from typing import Iterator
 
-import click
+import rich_click as click
 from housekeeper.store.models import Bundle, Version
 
 from cg.apps.environ import environ_email
+from cg.apps.scout.scoutapi import ScoutAPI
+from cg.apps.tb.models import TrailblazerAnalysis
 from cg.clients.chanjo2.models import CoverageMetrics
 from cg.constants import EXIT_FAIL, EXIT_SUCCESS, Priority, SequencingFileTag, Workflow
 from cg.constants.constants import (
-    AnalysisType,
     CaseActions,
     CustomerId,
     FileFormat,
@@ -21,17 +22,26 @@ from cg.constants.constants import (
     WorkflowManager,
 )
 from cg.constants.gene_panel import GenePanelCombo, GenePanelMasterList
+from cg.constants.priority import TrailblazerPriority
 from cg.constants.scout import HGNC_ID, ScoutExportFileName
-from cg.constants.tb import AnalysisStatus
-from cg.exc import AnalysisNotReadyError, BundleAlreadyAddedError, CgDataError, CgError
+from cg.constants.sequencing import SeqLibraryPrepCategory
+from cg.constants.tb import AnalysisType
+from cg.exc import (
+    AnalysisAlreadyStoredError,
+    AnalysisNotReadyError,
+    BundleAlreadyAddedError,
+    CaseNotFoundError,
+    CgDataError,
+    CgError,
+)
 from cg.io.controller import WriteFile
 from cg.meta.archive.archive import SpringArchiveAPI
 from cg.meta.meta import MetaAPI
 from cg.meta.workflow.fastq import FastqHandler
+from cg.meta.workflow.utils.utils import MAP_TO_TRAILBLAZER_PRIORITY
 from cg.models.analysis import AnalysisModel
 from cg.models.cg_config import CGConfig
 from cg.models.fastq import FastqFileMeta
-from cg.services.sequencing_qc_service import SequencingQCService
 from cg.store.models import Analysis, BedVersion, Case, CaseSample, Sample
 
 LOG = logging.getLogger(__name__)
@@ -55,6 +65,10 @@ class AnalysisAPI(MetaAPI):
     def __init__(self, workflow: Workflow, config: CGConfig):
         super().__init__(config=config)
         self.workflow = workflow
+        if self.workflow == Workflow.NALLO:
+            self.scout_api: ScoutAPI = self.scout_api_38
+        else:
+            self.scout_api: ScoutAPI = self.scout_api_37
         self._process = None
 
     @property
@@ -101,41 +115,16 @@ class AnalysisAPI(MetaAPI):
             LOG.info(f"No working directory for {case_id} exists")
             raise FileNotFoundError(f"No working directory for {case_id} exists")
 
-    def is_case_ready_for_analysis(self, case: Case) -> bool:
-        """Check if case is ready for analysis. If case passes sequencing QC and is set to analyze,
-        or has not been analyzed yet, or the latest analysis failed, the case is ready for analysis.
-        """
-        case_passed_sequencing_qc: bool = SequencingQCService.case_pass_sequencing_qc(case)
-        case_is_set_to_analyze: bool = case.action == CaseActions.ANALYZE
-        case_has_not_been_analyzed: bool = not case.latest_analyzed
-        case_latest_analysis_failed: bool = (
-            self.trailblazer_api.get_latest_analysis_status(case_id=case.internal_id)
-            == AnalysisStatus.FAILED
-        )
-        return case_passed_sequencing_qc and (
-            case_is_set_to_analyze or case_has_not_been_analyzed or case_latest_analysis_failed
-        )
-
-    def get_cases_ready_for_analysis(self):
-        """
-        Return cases that are ready for analysis. The case is ready if it passes the logic in the
-        get_cases_to_analyse method, and it has passed the pre-analysis quality check.
-        """
-        cases_to_analyse: list[Case] = self.get_cases_to_analyse()
-        cases_passing_quality_check: list[Case] = [
-            case for case in cases_to_analyse if SequencingQCService.case_pass_sequencing_qc(case)
-        ]
-        return cases_passing_quality_check
-
-    def get_priority_for_case(self, case_id: str) -> int:
-        """Get priority from the status db case priority"""
-        case: Case = self.status_db.get_case_by_internal_id(internal_id=case_id)
-        return case.priority or Priority.research
-
     def get_slurm_qos_for_case(self, case_id: str) -> str:
         """Get Quality of service (SLURM QOS) for the case."""
-        priority: int = self.get_priority_for_case(case_id=case_id)
-        return Priority.priority_to_slurm_qos().get(priority)
+        case: Case = self.status_db.get_case_by_internal_id(internal_id=case_id)
+        return case.slurm_priority
+
+    def get_trailblazer_priority(self, case_id: str) -> TrailblazerPriority:
+        """Get the priority for the case in Trailblazer."""
+        case: Case = self.status_db.get_case_by_internal_id(internal_id=case_id)
+        priority: Priority = case.priority
+        return MAP_TO_TRAILBLAZER_PRIORITY[priority]
 
     def get_workflow_manager(self) -> str:
         """Get workflow manager for a given workflow."""
@@ -168,17 +157,18 @@ class AnalysisAPI(MetaAPI):
         return None
 
     @staticmethod
-    def get_application_type(sample_obj: Sample) -> str:
+    def get_analysis_type(sample: Sample) -> str:
         """
-        Gets application type for sample. Only application types supported by trailblazer (or other)
+        Return the analysis type for sample.
+        Only analysis types supported by Trailblazer
         are valid outputs.
         """
-        prep_category: str = sample_obj.prep_category
+        prep_category: str = sample.prep_category
         if prep_category and prep_category.lower() in {
-            AnalysisType.TARGETED_GENOME_SEQUENCING,
-            AnalysisType.WHOLE_EXOME_SEQUENCING,
-            AnalysisType.WHOLE_GENOME_SEQUENCING,
-            AnalysisType.WHOLE_TRANSCRIPTOME_SEQUENCING,
+            SeqLibraryPrepCategory.TARGETED_GENOME_SEQUENCING,
+            SeqLibraryPrepCategory.WHOLE_EXOME_SEQUENCING,
+            SeqLibraryPrepCategory.WHOLE_GENOME_SEQUENCING,
+            SeqLibraryPrepCategory.WHOLE_TRANSCRIPTOME_SEQUENCING,
         }:
             return prep_category.lower()
         return AnalysisType.OTHER
@@ -186,7 +176,7 @@ class AnalysisAPI(MetaAPI):
     def get_case_application_type(self, case_id: str) -> str:
         """Returns the application type for samples in a case."""
         samples: list[Sample] = self.status_db.get_samples_by_case_id(case_id)
-        application_types: set[str] = {self.get_application_type(sample) for sample in samples}
+        application_types: set[str] = {self.get_analysis_type(sample) for sample in samples}
 
         if len(application_types) > 1:
             raise CgError(
@@ -197,7 +187,7 @@ class AnalysisAPI(MetaAPI):
 
     def are_case_samples_rna(self, case_id: str) -> bool:
         analysis_type: str = self.get_case_application_type(case_id)
-        return analysis_type == AnalysisType.WHOLE_TRANSCRIPTOME_SEQUENCING
+        return analysis_type == AnalysisType.WTS
 
     def get_case_source_type(self, case_id: str) -> str | None:
         """
@@ -215,14 +205,14 @@ class AnalysisAPI(MetaAPI):
         return source_types.pop()
 
     def has_case_only_exome_samples(self, case_id: str) -> bool:
-        """Returns True if the application type for all samples in a case is WES."""
+        """Returns True if the application type for all samples in a case is WHOLE_EXOME_SEQUENCING."""
         application_type: str = self.get_case_application_type(case_id)
-        return application_type == AnalysisType.WHOLE_EXOME_SEQUENCING
+        return application_type == AnalysisType.WES
 
-    def upload_bundle_housekeeper(
+    def create_housekeeper_bundle(
         self, case_id: str, dry_run: bool = False, force: bool = False
-    ) -> None:
-        """Storing bundle data in Housekeeper for a case."""
+    ) -> tuple[Bundle, Version]:
+        """Create and return bundle data in Housekeeper for a case."""
         LOG.info(f"Storing bundle data in Housekeeper for {case_id}")
         bundle_data: dict = self.get_hermes_transformed_deliverables(case_id=case_id, force=force)
         bundle_result: tuple[Bundle, Version] = self.housekeeper_api.add_bundle(
@@ -238,37 +228,66 @@ class AnalysisAPI(MetaAPI):
                 "The following files would be stored:\n%s",
                 "\n".join([f["path"] for f in bundle_data["files"]]),
             )
-            return
-        self.housekeeper_api.include(bundle_version)
-        self.housekeeper_api.add_commit(bundle_object)
-        self.housekeeper_api.add_commit(bundle_version)
-        LOG.info(
-            f"Analysis successfully stored in Housekeeper: {case_id} ({bundle_version.created_at})"
-        )
+        else:
+            self.housekeeper_api.include(bundle_version)
+            self.housekeeper_api.add_commit(bundle_object)
+            self.housekeeper_api.add_commit(bundle_version)
+            LOG.info(
+                f"Analysis successfully stored in Housekeeper: {case_id} ({bundle_version.created_at})"
+            )
+        return bundle_result
 
-    def upload_bundle_statusdb(
-        self, case_id: str, comment: str | None = None, dry_run: bool = False, force: bool = False
-    ) -> None:
+    def _create_analysis_statusdb(self, case: Case, trailblazer_id: int | None) -> None:
         """Storing an analysis bundle in StatusDB for a provided case."""
-        LOG.info(f"Storing analysis in StatusDB for {case_id}")
-        case_obj: Case = self.status_db.get_case_by_internal_id(case_id)
-        analysis_start: datetime.date = self.get_bundle_created_date(case_id)
-        workflow_version: str = self.get_workflow_version(case_id)
+        LOG.info(f"Storing analysis in StatusDB for {case.internal_id}")
+        is_primary: bool = len(case.analyses) == 0
+        analysis_start: datetime = datetime.now()
+        workflow_version: str = self.get_workflow_version(case.internal_id)
         new_analysis: Analysis = self.status_db.add_analysis(
             workflow=self.workflow,
             version=workflow_version,
-            completed_at=datetime.now() if not force else None,
-            primary=(len(case_obj.analyses) == 0),
+            completed_at=None,
+            primary=is_primary,
             started_at=analysis_start,
-            comment=comment,
+            trailblazer_id=trailblazer_id,
         )
-        new_analysis.case = case_obj
+        new_analysis.case = case
+        self.status_db.add_item_to_store(new_analysis)
+        self.status_db.commit_to_store()
+        LOG.info(f"Analysis successfully stored in StatusDB: {case.internal_id} : {analysis_start}")
+
+    def update_analysis_as_completed_statusdb(
+        self,
+        case_id: str,
+        hk_version_id: int,
+        comment: str | None = None,
+        dry_run: bool = False,
+        force: bool = False,
+    ) -> None:
+        """Mark the analysis of a case as completed in StatusDB.
+        This implies:
+            - Setting the completed_at date
+            - Adding a comment if provided
+        Raises:
+            AnalysisDoesNotExistError: If no analysis is found for the case.
+            AnalysisAlreadyStoredError: If the analysis is already marked as completed.
+        """
+        LOG.info(f"Marking analysis as completed in StatusDB for {case_id}")
+        analysis: Analysis = self.status_db.get_latest_started_analysis_for_case(case_id)
+        if not force and analysis.completed_at:
+            raise AnalysisAlreadyStoredError(
+                f"Analysis for case {case_id} already set as completed at {analysis.completed_at}"
+            )
         if dry_run:
             LOG.info("Dry-run: StatusDB changes will not be commited")
             return
-        self.status_db.session.add(new_analysis)
-        self.status_db.session.commit()
-        LOG.info(f"Analysis successfully stored in StatusDB: {case_id} : {analysis_start}")
+        self.status_db.update_analysis_completed_at(
+            analysis_id=analysis.id, completed_at=datetime.now()
+        )
+        self.status_db.update_analysis_housekeeper_version_id(
+            analysis_id=analysis.id, version_id=hk_version_id
+        )
+        self.status_db.update_analysis_comment(analysis_id=analysis.id, comment=comment)
 
     def get_deliverables_file_path(self, case_id: str) -> Path:
         raise NotImplementedError
@@ -276,32 +295,32 @@ class AnalysisAPI(MetaAPI):
     def get_analysis_finish_path(self, case_id: str) -> Path:
         raise NotImplementedError
 
-    def add_pending_trailblazer_analysis(
+    def _add_pending_trailblazer_analysis(
         self,
-        case_id: str,
+        case: Case,
         tower_workflow_id: str | None = None,
-    ) -> None:
-        self.check_analysis_ongoing(case_id)
-        application_type: str = self.get_application_type(
-            self.status_db.get_case_by_internal_id(case_id).links[0].sample
-        )
-        config_path: str = self.get_job_ids_path(case_id).as_posix()
+    ) -> TrailblazerAnalysis:
+        self.check_analysis_ongoing(case.internal_id)
+
+        analysis_type: str = self.get_analysis_type(case.links[0].sample)
+        config_path: str = self.get_job_ids_path(case.internal_id).as_posix()
         email: str = environ_email()
-        order_id: int = self._get_order_id_from_case_id(case_id)
-        out_dir: str = self.get_job_ids_path(case_id).parent.as_posix()
-        slurm_quality_of_service: str = self.get_slurm_qos_for_case(case_id)
-        ticket: str = self.status_db.get_latest_ticket_from_case(case_id)
+        order_id: int = self._get_order_id_from_case_id(case.internal_id)
+        out_dir: str = self.get_job_ids_path(case.internal_id).parent.as_posix()
+        priority: TrailblazerPriority = self.get_trailblazer_priority(case.internal_id)
+        ticket: str = self.status_db.get_latest_ticket_from_case(case.internal_id)
         workflow: Workflow = self.workflow
         workflow_manager: str = self.get_workflow_manager()
-        is_case_for_development: bool = self._is_case_for_development(case_id)
-        self.trailblazer_api.add_pending_analysis(
-            analysis_type=application_type,
-            case_id=case_id,
+        is_case_for_development: bool = self._is_case_for_development(case.internal_id)
+
+        tb_analysis: TrailblazerAnalysis = self.trailblazer_api.add_pending_analysis(
+            analysis_type=analysis_type,
+            case_id=case.internal_id,
             config_path=config_path,
             email=email,
             order_id=order_id,
             out_dir=out_dir,
-            slurm_quality_of_service=slurm_quality_of_service,
+            priority=priority,
             ticket=ticket,
             workflow=workflow,
             workflow_manager=workflow_manager,
@@ -309,6 +328,9 @@ class AnalysisAPI(MetaAPI):
             is_hidden=is_case_for_development,
         )
 
+        LOG.info(f"Submitted case {case.internal_id} to Trailblazer")
+        return tb_analysis
+
     def _is_case_for_development(self, case_id: str) -> bool:
         case: Case = self.status_db.get_case_by_internal_id(case_id)
         return case.customer.internal_id == CustomerId.CG_INTERNAL_CUSTOMER
@@ -351,10 +373,8 @@ class AnalysisAPI(MetaAPI):
             LOG.info(f"Dry-run: Action {action} would be set for case {case_id}")
             return
         if action in [None, *CaseActions.actions()]:
-            case: Case = self.status_db.get_case_by_internal_id(internal_id=case_id)
-            case.action = action
-            self.status_db.session.commit()
-            LOG.info("Action %s set for case %s", action, case_id)
+            self.status_db.update_case_action(action=action, case_internal_id=case_id)
+            LOG.info(f"Action '{action}' set for case {case_id}")
             return
         LOG.warning(
             f"Action '{action}' not permitted by StatusDB and will not be set for case {case_id}"
@@ -366,8 +386,8 @@ class AnalysisAPI(MetaAPI):
         )
         return analyses_to_clean
 
-    def get_cases_to_analyse(self) -> list[Case]:
-        return self.status_db.cases_to_analyse(workflow=self.workflow)
+    def get_cases_to_analyze(self, limit: int = None) -> list[Case]:
+        return self.status_db.get_cases_to_analyze(limit=limit, workflow=self.workflow)
 
     def get_cases_to_store(self) -> list[Case]:
         """Return cases where analysis finished successfully,
@@ -572,8 +592,8 @@ class AnalysisAPI(MetaAPI):
         """Add a cleaned at date for all analyses related to a case."""
         analyses: list = self.status_db.get_case_by_internal_id(internal_id=case_id).analyses
         LOG.info(f"Adding a cleaned at date for case {case_id}")
-        for analysis_obj in analyses:
-            analysis_obj.cleaned_at = analysis_obj.cleaned_at or datetime.now()
+        for analysis in analyses:
+            analysis.cleaned_at = analysis.cleaned_at or datetime.now()
             self.status_db.session.commit()
 
     def clean_run_dir(
@@ -735,6 +755,19 @@ class AnalysisAPI(MetaAPI):
     def run_analysis(self, *args, **kwargs):
         raise NotImplementedError
 
+    def on_analysis_started(self, case_id: str, tower_workflow_id: str | None = None):
+        if (case := self.status_db.get_case_by_internal_id(case_id)) is None:
+            raise CaseNotFoundError(
+                f"Failed to create analysis in Trailblazer and StatusDB, case {case_id} not found in StatusDB"
+            )
+
+        trailblazer_analysis: TrailblazerAnalysis = self._add_pending_trailblazer_analysis(
+            case=case, tower_workflow_id=tower_workflow_id
+        )
+
+        self._create_analysis_statusdb(case=case, trailblazer_id=trailblazer_analysis.id)
+        self.set_statusdb_action(case_id=case_id, action=CaseActions.RUNNING)
+
     def get_data_analysis_type(self, case_id: str) -> str | None:
         """
         Return data analysis type carried out.
