@@ -7,7 +7,7 @@ from housekeeper.store.models import File, Version
 from pydantic.v1 import EmailStr, ValidationError
 
 from cg.constants import Workflow
-from cg.constants.constants import FileFormat, SampleType, GenomeVersion
+from cg.constants.constants import FileFormat, GenomeVersion, SampleType
 from cg.constants.housekeeper_tags import BalsamicAnalysisTag
 from cg.constants.observations import ObservationsFileWildcards
 from cg.constants.priority import SlurmQos
@@ -36,8 +36,7 @@ MAX_CASES_TO_START_IN_50_MINUTES = 21
 
 
 class BalsamicAnalysisAPI(AnalysisAPI):
-    """Handles communication between BALSAMIC processes
-    and the rest of CG infrastructure"""
+    """Handles communication between BALSAMIC processes and the rest of CG infrastructure."""
 
     __BALSAMIC_APPLICATIONS = {"wgs", "wes", "tgs"}
     __BALSAMIC_BED_APPLICATIONS = {"wes", "tgs"}
@@ -49,21 +48,23 @@ class BalsamicAnalysisAPI(AnalysisAPI):
     ):
         super().__init__(workflow=workflow, config=config)
         self.account: str = config.balsamic.slurm.account
-        self.binary_path: str = config.balsamic.binary_path
         self.balsamic_cache: str = config.balsamic.balsamic_cache
+        self.bed_path: str = config.balsamic.bed_path
+        self.binary_path: str = config.balsamic.binary_path
+        self.cadd_path: str = config.balsamic.cadd_path
         self.conda_binary: str = config.balsamic.conda_binary
         self.conda_env: str = config.balsamic.conda_env
-        self.bed_path: str = config.balsamic.bed_path
-        self.cadd_path: str = config.balsamic.cadd_path
+        self.email: EmailStr = config.balsamic.slurm.mail_user
         self.genome_interval_path: str = config.balsamic.genome_interval_path
-        self.gnomad_af5_path: str = config.balsamic.gnomad_af5_path
         self.gens_coverage_female_path: str = config.balsamic.gens_coverage_female_path
         self.gens_coverage_male_path: str = config.balsamic.gens_coverage_male_path
-        self.email: EmailStr = config.balsamic.slurm.mail_user
+        self.gnomad_af5_path: str = config.balsamic.gnomad_af5_path
         self.loqusdb_path: str = config.balsamic.loqusdb_path
         self.pon_path: str = config.balsamic.pon_path
         self.qos: SlurmQos = config.balsamic.slurm.qos
         self.root_dir: str = config.balsamic.root
+        self.sentieon_licence_path: str = config.balsamic.sentieon_licence_path
+        self.sentieon_licence_server: str = config.sentieon_licence_server
         self.swegen_path: str = config.balsamic.swegen_path
 
     @property
@@ -92,14 +93,6 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         """Returns a path where the Balsamic case for the case_id should be located"""
         return Path(self.root_dir, case_id)
 
-    def get_cases_ready_for_analysis(self) -> list[Case]:
-        """Returns a list of cases that are ready for analysis."""
-        cases_to_analyse: list[Case] = self.get_cases_to_analyse()
-        cases_ready_for_analysis: list[Case] = [
-            case for case in cases_to_analyse if self.is_case_ready_for_analysis(case)
-        ]
-        return cases_ready_for_analysis[:MAX_CASES_TO_START_IN_50_MINUTES]
-
     def get_deliverables_file_path(self, case_id: str) -> Path:
         """Returns a path where the Balsamic deliverables file for the case_id should be located.
 
@@ -133,7 +126,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
             self.status_db.get_case_by_internal_id(internal_id=case_id).links
         )
 
-        application_type: str = self.get_application_type(
+        application_type: str = self.get_analysis_type(
             self.status_db.get_case_by_internal_id(internal_id=case_id).links[0].sample
         )
         sample_type = "tumor"
@@ -206,7 +199,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
             raise BalsamicStartError("Multiple application types found in LIMS")
         if not application_types.issubset(self.__BALSAMIC_BED_APPLICATIONS):
             if panel_bed:
-                raise BalsamicStartError("Cannot set panel_bed for WGS sample!")
+                raise BalsamicStartError("Cannot set panel_bed for WHOLE_GENOME_SEQUENCING sample!")
             return None
         if panel_bed:
             return panel_bed.as_posix()
@@ -349,7 +342,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
                 qc_metrics[sample_metric.id] = {sample_metric.name.lower(): sample_metric.value}
 
         return BalsamicAnalysis(
-            config=config_raw,
+            balsamic_config=config_raw,
             sample_metrics=self.cast_metrics_type(sequencing_type, qc_metrics),
         )
 
@@ -398,8 +391,12 @@ class BalsamicAnalysisAPI(AnalysisAPI):
 
         return verified_observations
 
-    def get_verified_gens_file_paths(self, sex: Sex) -> dict[str, str] | None:
+    def get_verified_gens_file_paths(self, sex: Sex, panel_bed: str) -> dict[str, str]:
         """Return a list of file path arguments for Gens."""
+        if panel_bed:
+            return {
+                "gnomad_min_af5": self.gnomad_af5_path,
+            }
         return {
             "genome_interval": self.genome_interval_path,
             "gnomad_min_af5": self.gnomad_af5_path,
@@ -417,6 +414,18 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         )
         return swegen_file
 
+    def should_soft_filter_normal(
+        self, config_case: dict, verified_panel_bed: str | None
+    ) -> dict[str, bool]:
+        """Sets soft_filter_normal to True for all TGA tumor normal paired analyses."""
+        return {
+            "soft_filter_normal": bool(
+                config_case["tumor_sample_name"]
+                and config_case["normal_sample_name"]
+                and verified_panel_bed
+            )
+        }
+
     def get_verified_config_case_arguments(
         self,
         case_id: str,
@@ -458,13 +467,19 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         }
 
         config_case.update(self.get_verified_samples(case_id=case_id))
-        config_case.update(self.get_parsed_observation_file_paths(observations))
-        (
-            config_case.update(self.get_verified_gens_file_paths(sex=verified_sex))
-            if not verified_panel_bed and genome_version == GenomeVersion.HG19
-            else None
+
+        config_case.update(
+            self.should_soft_filter_normal(
+                config_case=config_case, verified_panel_bed=verified_panel_bed
+            )
         )
 
+        config_case.update(self.get_parsed_observation_file_paths(observations))
+        if genome_version == GenomeVersion.HG19:
+            config_case.update(
+                self.get_verified_gens_file_paths(sex=verified_sex, panel_bed=verified_panel_bed)
+            )
+
         return config_case
 
     @staticmethod
@@ -496,7 +511,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
             link_object.sample.internal_id: {
                 "sex": link_object.sample.sex,
                 "tissue_type": self.get_sample_type(link_object.sample).value,
-                "application_type": self.get_application_type(link_object.sample),
+                "application_type": self.get_analysis_type(link_object.sample),
                 "target_bed": self.resolve_target_bed(panel_bed=panel_bed, link_object=link_object),
             }
             for link_object in self.status_db.get_case_by_internal_id(internal_id=case_id).links
@@ -508,7 +523,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
     def resolve_target_bed(self, panel_bed: str | None, link_object: CaseSample) -> str | None:
         if panel_bed:
             return panel_bed
-        if self.get_application_type(link_object.sample) not in self.__BALSAMIC_BED_APPLICATIONS:
+        if self.get_analysis_type(link_object.sample) not in self.__BALSAMIC_BED_APPLICATIONS:
             return None
         return self.get_target_bed_from_lims(link_object.case.internal_id)
 
@@ -547,6 +562,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
                 "--balsamic-cache": self.balsamic_cache,
                 "--cache-version": cache_version,
                 "--cadd-annotations": self.cadd_path,
+                "--artefact-snv-observations": arguments.get("artefact_somatic_snv"),
                 "--cancer-germline-snv-observations": arguments.get("cancer_germline_snv"),
                 "--cancer-germline-sv-observations": arguments.get("cancer_germline_sv"),
                 "--cancer-somatic-snv-observations": arguments.get("cancer_somatic_snv"),
@@ -564,12 +580,14 @@ class BalsamicAnalysisAPI(AnalysisAPI):
                 "--gnomad-min-af5": arguments.get("gnomad_min_af5"),
                 "--normal-sample-name": arguments.get("normal_sample_name"),
                 "--panel-bed": arguments.get("panel_bed"),
-                "--exome": arguments.get("exome"),
                 "--pon-cnn": arguments.get("pon_cnn"),
+                "--exome": arguments.get("exome"),
+                "--sentieon-install-dir": self.sentieon_licence_path,
+                "--sentieon-license": self.sentieon_licence_server,
+                "--soft-filter-normal": arguments.get("soft_filter_normal"),
                 "--swegen-snv": arguments.get("swegen_snv"),
                 "--swegen-sv": arguments.get("swegen_sv"),
                 "--tumor-sample-name": arguments.get("tumor_sample_name"),
-                "--umi-trim-length": arguments.get("umi_trim_length"),
             },
             exclude_true=True,
         )
@@ -615,7 +633,7 @@ class BalsamicAnalysisAPI(AnalysisAPI):
     def get_genome_build(self, case_id: str) -> str:
         """Returns the reference genome build version of a Balsamic analysis."""
         analysis_metadata: BalsamicAnalysis = self.get_latest_metadata(case_id)
-        return analysis_metadata.config.reference.reference_genome_version
+        return analysis_metadata.balsamic_config.reference.reference_genome_version
 
     @staticmethod
     def get_variant_caller_version(var_caller_name: str, var_caller_versions: dict) -> str | None:
@@ -631,10 +649,10 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         config.json file.
         """
         analysis_metadata: BalsamicAnalysis = self.get_latest_metadata(case_id)
-        sequencing_type: str = analysis_metadata.config.analysis.sequencing_type
-        analysis_type: str = analysis_metadata.config.analysis.analysis_type
-        var_callers: dict[str, BalsamicVarCaller] = analysis_metadata.config.vcf
-        tool_versions: dict[str, list] = analysis_metadata.config.bioinfo_tools_version
+        sequencing_type: str = analysis_metadata.balsamic_config.analysis.sequencing_type
+        analysis_type: str = analysis_metadata.balsamic_config.analysis.analysis_type
+        var_callers: dict[str, BalsamicVarCaller] = analysis_metadata.balsamic_config.vcf
+        tool_versions: dict[str, list] = analysis_metadata.balsamic_config.bioinfo_tools_version
         analysis_var_callers = []
         for var_caller_name, var_caller_attributes in var_callers.items():
             if (
@@ -653,8 +671,8 @@ class BalsamicAnalysisAPI(AnalysisAPI):
         """Return list of panel of normals used for analysis."""
         pons: list[str] = []
         analysis_metadata: BalsamicAnalysis = self.get_latest_metadata(case_id)
-        if analysis_metadata.config.panel:
-            if pon_cnn := analysis_metadata.config.panel.pon_cnn:
+        if analysis_metadata.balsamic_config.panel:
+            if pon_cnn := analysis_metadata.balsamic_config.panel.pon_cnn:
                 pons.append(pon_cnn)
         return pons
 
