@@ -2,7 +2,7 @@ import logging
 from pathlib import Path
 from typing import Any
 
-from pydantic.v1 import ValidationError
+from pydantic import ValidationError
 
 from cg.apps.mip.confighandler import ConfigHandler
 from cg.constants import FileExtensions, Workflow
@@ -249,14 +249,6 @@ class MipAnalysisAPI(AnalysisAPI):
                 return True
         return False
 
-    def get_cases_ready_for_analysis(self) -> list[Case]:
-        """Return cases to analyze."""
-        cases_to_analyse: list[Case] = self.get_cases_to_analyse()
-        cases_ready_for_analysis: list[Case] = [
-            case for case in cases_to_analyse if self.is_case_ready_for_analysis(case)
-        ]
-        return cases_ready_for_analysis[:MAX_CASES_TO_START_IN_50_MINUTES]
-
     @staticmethod
     def _append_value_for_non_flags(parameters: list, value) -> None:
         """Add the value of the non boolean options to the parameters"""
