@@ -2,7 +2,7 @@ import logging
 from pathlib import Path
 from typing import Any
 
-from pydantic.v1 import BaseModel, EmailStr, Field
+from pydantic import BaseModel, ConfigDict, EmailStr, Field
 from typing_extensions import Literal
 
 from cg.apps.coverage import ChanjoAPI
@@ -26,16 +26,13 @@ from cg.constants.observations import LoqusdbInstance
 from cg.constants.priority import SlurmQos
 from cg.meta.delivery.delivery import DeliveryAPI
 from cg.services.analysis_service.analysis_service import AnalysisService
+from cg.services.decompression_service.decompressor import Decompressor
+from cg.services.deliver_files.factory import DeliveryServiceFactory
+from cg.services.deliver_files.rsync.models import RsyncDeliveryConfig
+from cg.services.deliver_files.rsync.service import DeliveryRsyncService
 from cg.services.fastq_concatenation_service.fastq_concatenation_service import (
     FastqConcatenationService,
 )
-from cg.services.deliver_files.deliver_files_service.deliver_files_service_factory import (
-    DeliveryServiceFactory,
-)
-from cg.services.deliver_files.delivery_rsync_service.delivery_rsync_service import (
-    DeliveryRsyncService,
-)
-from cg.services.deliver_files.delivery_rsync_service.models import RsyncDeliveryConfig
 from cg.services.pdc_service.pdc_service import PdcService
 from cg.services.run_devices.pacbio.data_storage_service.pacbio_store_service import (
     PacBioStoreService,
@@ -51,14 +48,17 @@ from cg.services.run_devices.pacbio.post_processing_service import PacBioPostPro
 from cg.services.run_devices.pacbio.run_data_generator.pacbio_run_data_generator import (
     PacBioRunDataGenerator,
 )
-from cg.services.run_devices.pacbio.run_file_manager.run_file_manager import (
-    PacBioRunFileManager,
-)
+from cg.services.run_devices.pacbio.run_file_manager.run_file_manager import PacBioRunFileManager
+from cg.services.run_devices.pacbio.run_validator.pacbio_run_validator import PacBioRunValidator
+from cg.services.run_devices.run_names.pacbio import PacbioRunNamesService
 from cg.services.sequencing_qc_service.sequencing_qc_service import SequencingQCService
 from cg.services.slurm_service.slurm_cli_service import SlurmCLIService
 from cg.services.slurm_service.slurm_service import SlurmService
 from cg.services.slurm_upload_service.slurm_upload_config import SlurmUploadConfig
 from cg.services.slurm_upload_service.slurm_upload_service import SlurmUploadService
+from cg.services.validate_file_transfer_service.validate_file_transfer_service import (
+    ValidateFileTransferService,
+)
 from cg.store.database import initialize_database
 from cg.store.store import Store
 
@@ -77,11 +77,11 @@ class ArnoldConfig(BaseModel):
 
 class SlurmConfig(BaseModel):
     account: str
-    hours: int | None
+    hours: int | None = None
     mail_user: EmailStr
-    memory: int | None
-    number_tasks: int | None
-    conda_env: str | None
+    memory: int | None = None
+    number_tasks: int | None = None
+    conda_env: str | None = None
     qos: SlurmQos = SlurmQos.LOW
 
 
@@ -131,7 +131,7 @@ class TrailblazerConfig(BaseModel):
 
 
 class StatinaConfig(BaseModel):
-    host: str | None
+    host: str | None = None
     user: str
     key: str
     api_url: str
@@ -140,8 +140,13 @@ class StatinaConfig(BaseModel):
 
 
 class CommonAppConfig(BaseModel):
-    binary_path: str | None
-    config_path: str | None
+    binary_path: str | None = None
+    config_path: str | None = None
+    container_mount_volume: str | None = None
+
+
+class HermesConfig(CommonAppConfig):
+    container_path: str
 
 
 class FluffyUploadConfig(BaseModel):
@@ -208,18 +213,38 @@ class MipConfig(BaseModel):
     script: str
 
 
+class NalloConfig(CommonAppConfig):
+    binary_path: str | None = None
+    compute_env: str
+    conda_binary: str | None = None
+    conda_env: str
+    platform: str
+    params: str
+    config: str
+    resources: str
+    launch_directory: str
+    workflow_bin_path: str
+    profile: str
+    revision: str
+    root: str
+    slurm: SlurmConfig
+    tower_workflow: str
+
+
 class RarediseaseConfig(CommonAppConfig):
     binary_path: str | None = None
     compute_env: str
     conda_binary: str | None = None
     conda_env: str
-    config_platform: str
-    config_params: str
-    config_resources: str
+    platform: str
+    params: str
+    config: str
+    resources: str
     launch_directory: str
-    workflow_path: str
+    workflow_bin_path: str
+    pre_run_script: str = ""
     profile: str
-    references: str
+    repository: str
     revision: str
     root: str
     slurm: SlurmConfig
@@ -231,12 +256,12 @@ class TomteConfig(CommonAppConfig):
     compute_env: str
     conda_binary: str | None = None
     conda_env: str
-    config_platform: str
-    config_params: str
-    config_resources: str
-    workflow_path: str
+    platform: str
+    params: str
+    config: str
+    resources: str
+    workflow_bin_path: str
     profile: str
-    references: str
     revision: str
     root: str
     slurm: SlurmConfig
@@ -244,18 +269,21 @@ class TomteConfig(CommonAppConfig):
 
 
 class RnafusionConfig(CommonAppConfig):
-    root: str
-    references: str
     binary_path: str
-    workflow_path: str
-    conda_env: str
     compute_env: str
-    profile: str
     conda_binary: str | None = None
+    conda_env: str
+    platform: str
+    params: str
+    config: str
+    resources: str
     launch_directory: str
+    profile: str
     revision: str
+    root: str
     slurm: SlurmConfig
     tower_workflow: str
+    workflow_bin_path: str
 
 
 class TaxprofilerConfig(CommonAppConfig):
@@ -263,9 +291,11 @@ class TaxprofilerConfig(CommonAppConfig):
     conda_binary: str | None = None
     conda_env: str
     compute_env: str
-    databases: str
-    hostremoval_reference: str
-    workflow_path: str
+    platform: str
+    params: str
+    config: str
+    resources: str
+    workflow_bin_path: str
     profile: str
     revision: str
     root: str
@@ -275,7 +305,7 @@ class TaxprofilerConfig(CommonAppConfig):
 
 class MicrosaltConfig(BaseModel):
     binary_path: str
-    conda_binary: str | None = None
+    conda_binary: str
     conda_env: str
     queries_path: str
     root: str
@@ -319,6 +349,13 @@ class ExternalConfig(BaseModel):
     caesar: str
 
 
+class SeqeraPlatformConfig(BaseModel):
+    base_url: str
+    bearer_token: str
+    compute_environments: dict[SlurmQos, str]
+    workspace_id: int
+
+
 class DataFlowConfig(BaseModel):
     database_name: str
     user: str
@@ -349,11 +386,14 @@ class RunInstruments(BaseModel):
     illumina: IlluminaConfig
 
 
+class RunNamesServices(BaseModel):
+    pacbio: PacbioRunNamesService
+    model_config = ConfigDict(arbitrary_types_allowed=True)
+
+
 class PostProcessingServices(BaseModel):
     pacbio: PacBioPostProcessingService
-
-    class Config:
-        arbitrary_types_allowed = True
+    model_config = ConfigDict(arbitrary_types_allowed=True)
 
 
 class CGConfig(BaseModel):
@@ -364,7 +404,7 @@ class CGConfig(BaseModel):
     email_base_settings: EmailBaseSettings
     environment: Literal["production", "stage"] = "stage"
     madeline_exe: str
-    max_flowcells: int | None
+    max_flowcells: int | None = None
     nanopore_data_directory: str
     run_instruments: RunInstruments
     sentieon_licence_server: str
@@ -398,7 +438,7 @@ class CGConfig(BaseModel):
     genotype_api_: GenotypeAPI = None
     gens: CommonAppConfig = None
     gens_api_: GensAPI = None
-    hermes: CommonAppConfig = None
+    hermes: HermesConfig = None
     hermes_api_: HermesApi = None
     janus: ClientConfig | None = None
     janus_api_: JanusAPIClient | None = None
@@ -406,6 +446,7 @@ class CGConfig(BaseModel):
     lims_api_: LimsAPI = None
     loqusdb: CommonAppConfig = Field(None, alias=LoqusdbInstance.WGS.value)
     loqusdb_api_: LoqusdbAPI = None
+    loqusdb_rd_lwp: CommonAppConfig = Field(None, alias=LoqusdbInstance.LWP.value)
     loqusdb_somatic: CommonAppConfig = Field(None, alias=LoqusdbInstance.SOMATIC.value)
     loqusdb_tumor: CommonAppConfig = Field(None, alias=LoqusdbInstance.TUMOR.value)
     loqusdb_wes: CommonAppConfig = Field(None, alias=LoqusdbInstance.WES.value)
@@ -413,12 +454,16 @@ class CGConfig(BaseModel):
     mutacc_auto: MutaccAutoConfig = Field(None, alias="mutacc-auto")
     mutacc_auto_api_: MutaccAutoAPI = None
     pdc: CommonAppConfig | None = None
-    pdc_service_: PdcService | None
+    pdc_service_: PdcService | None = None
     post_processing_services_: PostProcessingServices | None = None
     pigz: CommonAppConfig | None = None
+    run_names_services_: RunNamesServices | None = None
     sample_sheet_api_: IlluminaSampleSheetService | None = None
+    seqera_platform: SeqeraPlatformConfig | None = None
     scout: CommonAppConfig = None
-    scout_api_: ScoutAPI = None
+    scout_38: CommonAppConfig = None
+    scout_api_37_: ScoutAPI = None
+    scout_api_38_: ScoutAPI = None
     tar: CommonAppConfig | None = None
     trailblazer: TrailblazerConfig = None
     trailblazer_api_: TrailblazerAPI = None
@@ -432,6 +477,7 @@ class CGConfig(BaseModel):
     mip_rd_dna: MipConfig | None = Field(None, alias="mip-rd-dna")
     mip_rd_rna: MipConfig | None = Field(None, alias="mip-rd-rna")
     mutant: MutantConfig | None = None
+    nallo: NalloConfig | None = None
     raredisease: RarediseaseConfig | None = None
     rnafusion: RnafusionConfig | None = None
     statina: StatinaConfig | None = None
@@ -441,29 +487,7 @@ class CGConfig(BaseModel):
     # These are meta APIs that gets instantiated in the code
     meta_apis: dict = {}
 
-    class Config:
-        arbitrary_types_allowed = True
-        fields = {
-            "arnold_api_": "arnold_api",
-            "chanjo_api_": "chanjo_api",
-            "chanjo2_api_": "chanjo2_api",
-            "crunchy_api_": "crunchy_api",
-            "demultiplex_api_": "demultiplex_api",
-            "genotype_api_": "genotype_api",
-            "gens_api_": "gens_api",
-            "hermes_api_": "hermes_api",
-            "housekeeper_api_": "housekeeper_api",
-            "lims_api_": "lims_api",
-            "loqusdb_api_": "loqusdb_api",
-            "madeline_api_": "madeline_api",
-            "mutacc_auto_api_": "mutacc_auto_api",
-            "pdc_service_": "pdc_service",
-            "post_processing_services_": "post_processing_services",
-            "scout_api_": "scout_api",
-            "status_db_": "status_db",
-            "trailblazer_api_": "trailblazer_api",
-            "janus_api_": "janus_api",
-        }
+    model_config = ConfigDict(arbitrary_types_allowed=True)
 
     @property
     def arnold_api(self) -> ArnoldAPIClient:
@@ -612,6 +636,11 @@ class CGConfig(BaseModel):
         LOG.debug("Instantiating PacBio post-processing service")
         run_data_generator = PacBioRunDataGenerator()
         file_manager = PacBioRunFileManager()
+        run_validator = PacBioRunValidator(
+            file_manager=file_manager,
+            decompressor=Decompressor(),
+            file_transfer_validator=ValidateFileTransferService(),
+        )
         metrics_parser = PacBioMetricsParser(file_manager=file_manager)
         transfer_service = PacBioDataTransferService(metrics_service=metrics_parser)
         store_service = PacBioStoreService(
@@ -623,6 +652,7 @@ class CGConfig(BaseModel):
             metrics_parser=metrics_parser,
         )
         return PacBioPostProcessingService(
+            run_validator=run_validator,
             run_data_generator=run_data_generator,
             hk_service=hk_service,
             store_service=store_service,
@@ -638,6 +668,17 @@ class CGConfig(BaseModel):
             self.pdc_service_ = service
         return service
 
+    @property
+    def run_names_services(self) -> RunNamesServices:
+        services = self.run_names_services_
+        if services is None:
+            LOG.debug("Instantiating run directory names services")
+            services = RunNamesServices(
+                pacbio=PacbioRunNamesService(self.run_instruments.pacbio.data_dir)
+            )
+            self.run_names_services_ = services
+        return services
+
     @property
     def sample_sheet_api(self) -> IlluminaSampleSheetService:
         sample_sheet_api = self.__dict__.get("sample_sheet_api_")
@@ -673,12 +714,23 @@ class CGConfig(BaseModel):
         return AnalysisService(analysis_client=self.trailblazer_api, status_db=self.status_db)
 
     @property
-    def scout_api(self) -> ScoutAPI:
-        api = self.__dict__.get("scout_api_")
+    def scout_api_37(self) -> ScoutAPI:
+        api = self.scout_api_37_
+        if not api:
+            LOG.debug("Instantiating scout api, genome build 37")
+            api = ScoutAPI(scout_config=self.scout, slurm_upload_service=self.slurm_upload_service)
+            self.scout_api_37_ = api
+        return api
+
+    @property
+    def scout_api_38(self) -> ScoutAPI:
+        api = self.scout_api_38_
         if api is None:
-            LOG.debug("Instantiating scout api")
-            api = ScoutAPI(config=self.dict(), slurm_upload_service=self.slurm_upload_service)
-            self.scout_api_ = api
+            LOG.debug("Instantiating scout api, genome build 38")
+            api = ScoutAPI(
+                scout_config=self.scout_38, slurm_upload_service=self.slurm_upload_service
+            )
+            self.scout_api_38_ = api
         return api
 
     @property
@@ -743,6 +795,7 @@ class CGConfig(BaseModel):
             LOG.debug("Instantiating delivery service factory")
             factory = DeliveryServiceFactory(
                 store=self.status_db,
+                lims_api=self.lims_api,
                 hk_api=self.housekeeper_api,
                 tb_service=self.trailblazer_api,
                 rsync_service=self.delivery_rsync_service,
