@@ -1,4 +1,5 @@
 from enum import StrEnum
+from pathlib import Path
 
 from cg.constants.constants import SexOptions
 from cg.models.nf_analysis import NextflowSampleSheetEntry, WorkflowParameters
@@ -64,9 +65,9 @@ class RarediseaseSampleSheetHeaders(StrEnum):
 class RarediseaseParameters(WorkflowParameters):
     """Model for Raredisease parameters."""
 
-    target_bed: str
+    target_bed_file: str
     analysis_type: str
     save_mapped_as_cram: bool
-    skip_germlinecnvcaller: bool
     vcfanno_extra_resources: str
-    local_genomes: str
+    vep_filters_scout_fmt: str
+    sample_id_map: Path
