@@ -15,12 +15,11 @@ class Sbatch(BaseModel):
     quality_of_service: SlurmQos = SlurmQos.LOW
     commands: str
     error: str | None = None
-    exclude: str | None = ""
+    exclude: str | None = None
     number_tasks: int | None = None
     memory: int | None = None
+    dependency: str | None = None
 
 
 class SbatchDragen(Sbatch):
     partition: str = HastaSlurmPartitions.DRAGEN
-    nodes: int = 1
-    cpus_per_task: int = 24
