@@ -9,12 +9,14 @@ from cg.constants.housekeeper_tags import SequencingFileTag
 from cg.constants.sequencing import Sequencers
 from cg.models.run_devices.illumina_run_directory_data import IlluminaRunDirectoryData
 from cg.services.illumina.post_processing.utils import (
+    is_sample_negative_control_with_reads_in_lane,
     get_lane_from_sample_fastq,
     get_q30_threshold,
     get_sample_fastqs_from_flow_cell,
     get_undetermined_fastqs,
     rename_fastq_file_if_needed,
 )
+from cg.store.models import Sample
 from cg.store.store import Store
 from cg.utils.files import get_files_matching_pattern
 
@@ -32,6 +34,7 @@ def _should_fastq_path_be_stored_in_housekeeper(
     Check if a sample fastq file should be tracked in Housekeeper.
     Only fastq files that pass the q30 threshold should be tracked.
     """
+    sample: Sample = store.get_sample_by_internal_id(internal_id=sample_id)
 
     lane = get_lane_from_sample_fastq(sample_fastq_path)
     q30_threshold: int = get_q30_threshold(sequencer_type)
@@ -43,6 +46,12 @@ def _should_fastq_path_be_stored_in_housekeeper(
     )
 
     if metric:
+
+        if is_sample_negative_control_with_reads_in_lane(
+            is_negative_control=sample.is_negative_control, metric=metric
+        ):
+            return True
+
         return metric.base_passing_q30_percent >= q30_threshold
 
     LOG.warning(
