@@ -3,6 +3,7 @@ from datetime import datetime
 from enum import Enum
 from typing import Annotated
 
+import sqlalchemy
 from sqlalchemy import (
     BLOB,
     DECIMAL,
@@ -24,14 +25,15 @@ from cg.constants.archiving import PDC_ARCHIVE_LOCATION
 from cg.constants.constants import (
     CaseActions,
     ControlOptions,
-    PrepCategory,
     SequencingQCStatus,
     SexOptions,
     StatusOptions,
 )
 from cg.constants.devices import DeviceType
 from cg.constants.priority import SlurmQos
+from cg.constants.sequencing import SeqLibraryPrepCategory
 from cg.constants.symbols import EMPTY_STRING
+from cg.models.orders.constants import OrderType
 
 BigInt = Annotated[int, None]
 Blob = Annotated[bytes, None]
@@ -144,7 +146,7 @@ class Application(Base):
 
     tag: Mapped[UniqueStr]
     prep_category: Mapped[str] = mapped_column(
-        types.Enum(*(category.value for category in PrepCategory))
+        types.Enum(*(category.value for category in SeqLibraryPrepCategory))
     )
     is_external: Mapped[bool] = mapped_column(default=False)
     description: Mapped[Str256]
@@ -179,6 +181,22 @@ class Application(Base):
     pipeline_limitations: Mapped[list["ApplicationLimitations"]] = orm.relationship(
         back_populates="application"
     )
+    order_type_applications: Mapped[list["OrderTypeApplication"]] = orm.relationship(
+        "OrderTypeApplication",
+        back_populates="application",
+    )
+
+    @property
+    def order_types(self) -> list[OrderType]:
+        return [entry.order_type for entry in self.order_type_applications]
+
+    @order_types.setter
+    def order_types(self, order_types: list[OrderType]) -> None:
+        self.order_type_applications.clear()
+        self.order_type_applications = [
+            OrderTypeApplication(order_type=order_type, application_id=self.id)
+            for order_type in order_types
+        ]
 
     def __str__(self) -> str:
         return self.tag
@@ -193,13 +211,13 @@ class Application(Base):
 
     @property
     def analysis_type(self) -> str:
-        if self.prep_category == PrepCategory.WHOLE_TRANSCRIPTOME_SEQUENCING.value:
-            return PrepCategory.WHOLE_TRANSCRIPTOME_SEQUENCING.value
+        if self.prep_category == SeqLibraryPrepCategory.WHOLE_TRANSCRIPTOME_SEQUENCING.value:
+            return SeqLibraryPrepCategory.WHOLE_TRANSCRIPTOME_SEQUENCING.value
 
         return (
-            PrepCategory.WHOLE_GENOME_SEQUENCING.value
-            if self.prep_category == PrepCategory.WHOLE_GENOME_SEQUENCING.value
-            else PrepCategory.WHOLE_EXOME_SEQUENCING.value
+            SeqLibraryPrepCategory.WHOLE_GENOME_SEQUENCING.value
+            if self.prep_category == SeqLibraryPrepCategory.WHOLE_GENOME_SEQUENCING.value
+            else SeqLibraryPrepCategory.WHOLE_EXOME_SEQUENCING.value
         )
 
     def to_dict(self):
@@ -265,7 +283,7 @@ class Analysis(Base):
     workflow: Mapped[str | None] = mapped_column(
         types.Enum(*(workflow.value for workflow in Workflow))
     )
-    workflow_version: Mapped[Str32 | None]
+    workflow_version: Mapped[Str64 | None]
     started_at: Mapped[datetime | None]
     completed_at: Mapped[datetime | None]
     delivery_report_created_at: Mapped[datetime | None]
@@ -278,6 +296,8 @@ class Analysis(Base):
     comment: Mapped[Text | None]
     case_id: Mapped[int] = mapped_column(ForeignKey("case.id", ondelete="CASCADE"))
     case: Mapped["Case"] = orm.relationship(back_populates="analyses")
+    trailblazer_id: Mapped[int | None]
+    housekeeper_version_id: Mapped[int | None]
 
     def __str__(self):
         return f"{self.case.internal_id} | {self.completed_at.date()}"
@@ -436,7 +456,7 @@ class Case(Base, PriorityMixin):
     created_at: Mapped[datetime | None] = mapped_column(default=datetime.now)
     customer_id: Mapped[int] = mapped_column(ForeignKey("customer.id", ondelete="CASCADE"))
     customer: Mapped["Customer"] = orm.relationship(foreign_keys=[customer_id])
-    data_analysis: Mapped[str | None] = mapped_column(
+    data_analysis: Mapped[str] = mapped_column(
         types.Enum(*(workflow.value for workflow in Workflow))
     )
     data_delivery: Mapped[str | None] = mapped_column(
@@ -460,7 +480,7 @@ class Case(Base, PriorityMixin):
     tickets: Mapped[VarChar128 | None]
 
     analyses: Mapped[list[Analysis]] = orm.relationship(
-        back_populates="case", order_by="-Analysis.completed_at"
+        back_populates="case", order_by="-Analysis.created_at"
     )
     links: Mapped[list["CaseSample"]] = orm.relationship(back_populates="case")
     orders: Mapped[list["Order"]] = orm.relationship(secondary=order_case, back_populates="cases")
@@ -496,9 +516,22 @@ class Case(Base, PriorityMixin):
         )
         return sorted_orders[0]
 
+    @property
+    def latest_completed_analysis(self) -> Analysis | None:
+        """Returns the latest completed analysis for this case."""
+        valid_analyses: list[Analysis] = [a for a in self.analyses if a.completed_at is not None]
+        if not valid_analyses:
+            return None
+        sorted_analyses: list[Analysis] = sorted(
+            valid_analyses, key=lambda analysis: analysis.completed_at, reverse=True
+        )
+        return sorted_analyses[0]
+
     @property
     def latest_analyzed(self) -> datetime | None:
-        return self.analyses[0].completed_at if self.analyses else None
+        return (
+            self.latest_completed_analysis.completed_at if self.latest_completed_analysis else None
+        )
 
     @property
     def latest_sequenced(self) -> datetime | None:
@@ -514,6 +547,13 @@ class Case(Base, PriorityMixin):
     def are_all_samples_sequenced(self) -> bool:
         return all([link.sample.last_sequenced_at for link in self.links])
 
+    def are_all_samples_control(self) -> bool:
+        """Return True if all case samples are controls."""
+        return all(
+            sample.control in [ControlOptions.NEGATIVE, ControlOptions.POSITIVE]
+            for sample in self.samples
+        )
+
     def __str__(self) -> str:
         return f"{self.internal_id} ({self.name})"
 
@@ -548,17 +588,18 @@ class Case(Base, PriorityMixin):
         return self.analyses and self.analyses[0].uploaded_at
 
     @property
-    def slurm_priority(self) -> SlurmQos:
-        case_priority: str = self.priority
-        slurm_priority: str = Priority.priority_to_slurm_qos().get(case_priority)
-        return SlurmQos(slurm_priority)
+    def slurm_priority(self) -> str:
+        """Get Quality of service (SLURM QOS) for the case."""
+        if self.are_all_samples_control():
+            return SlurmQos.EXPRESS
+        return Priority.priority_to_slurm_qos().get(self.priority)
 
     def get_delivery_arguments(self) -> set[str]:
         """Translates the case data_delivery field to workflow specific arguments."""
         delivery_arguments: set[str] = set()
         requested_deliveries: list[str] = re.split("[-_]", self.data_delivery)
         delivery_per_workflow_map: dict[str, str] = {
-            DataDelivery.FASTQ: Workflow.FASTQ,
+            DataDelivery.FASTQ: Workflow.RAW_DATA,
             DataDelivery.ANALYSIS_FILES: self.data_analysis,
         }
         for data_delivery, workflow in delivery_per_workflow_map.items():
@@ -575,9 +616,7 @@ class Case(Base, PriorityMixin):
         if links:
             data["links"] = [link_obj.to_dict(samples=True) for link_obj in self.links]
         if analyses:
-            data["analyses"] = [
-                analysis_obj.to_dict(family=False) for analysis_obj in self.analyses
-            ]
+            data["analyses"] = [analysis.to_dict(family=False) for analysis in self.analyses]
         return data
 
 
@@ -797,6 +836,11 @@ class Sample(Base, PriorityMixin):
         back_populates="sample", cascade="all, delete"
     )
 
+    def __init__(self, **kwargs):
+        for key, value in kwargs.items():
+            if hasattr(self, key):
+                setattr(self, key, value)
+
     def __str__(self) -> str:
         return f"{self.internal_id} ({self.name})"
 
@@ -818,6 +862,10 @@ class Sample(Base, PriorityMixin):
     def is_negative_control(self) -> bool:
         return self.control == ControlOptions.NEGATIVE
 
+    @property
+    def is_external(self) -> bool:
+        return self.application_version.application.is_external
+
     @property
     def flow_cells(self) -> list[Flowcell]:
         """Return the flow cells a sample has been sequenced on."""
@@ -967,14 +1015,20 @@ class Order(Base):
 
     __tablename__ = "order"
 
+    def __str__(self) -> str:
+        return f"{self.id} (ticket {self.ticket_id})"
+
     id: Mapped[PrimaryKeyInt]
     cases: Mapped[list[Case]] = orm.relationship(secondary=order_case, back_populates="orders")
     customer_id: Mapped[int] = mapped_column(ForeignKey("customer.id"))
     customer: Mapped[Customer] = orm.relationship(foreign_keys=[customer_id])
     order_date: Mapped[datetime] = mapped_column(default=datetime.now)
     ticket_id: Mapped[int] = mapped_column(unique=True, index=True)
-    workflow: Mapped[str] = mapped_column(types.Enum(*(workflow.value for workflow in Workflow)))
-    is_delivered: Mapped[bool] = mapped_column(default=False)
+    is_open: Mapped[bool] = mapped_column(default=True)
+
+    @property
+    def workflow(self) -> Workflow:
+        return self.cases[0].data_analysis
 
     def to_dict(self):
         return to_dict(model_instance=self)
@@ -1014,7 +1068,9 @@ class IlluminaFlowCell(RunDevice):
 
     __tablename__ = "illumina_flow_cell"
 
-    id: Mapped[int] = mapped_column(ForeignKey("run_device.id"), primary_key=True)
+    id: Mapped[int] = mapped_column(
+        ForeignKey("run_device.id", ondelete="CASCADE"), primary_key=True
+    )
     model: Mapped[str | None] = mapped_column(
         types.Enum("10B", "25B", "1.5B", "S1", "S2", "S4", "SP")
     )
@@ -1022,12 +1078,14 @@ class IlluminaFlowCell(RunDevice):
     __mapper_args__ = {"polymorphic_identity": DeviceType.ILLUMINA}
 
 
-class PacBioSMRTCell(RunDevice):
+class PacbioSMRTCell(RunDevice):
     """Model for storing PacBio SMRT cells."""
 
     __tablename__ = "pacbio_smrt_cell"
 
-    id: Mapped[int] = mapped_column(ForeignKey("run_device.id"), primary_key=True)
+    id: Mapped[int] = mapped_column(
+        ForeignKey("run_device.id", ondelete="CASCADE"), primary_key=True
+    )
 
     __mapper_args__ = {"polymorphic_identity": DeviceType.PACBIO}
 
@@ -1039,7 +1097,7 @@ class InstrumentRun(Base):
 
     id: Mapped[PrimaryKeyInt]
     type: Mapped[DeviceType]
-    device_id: Mapped[int] = mapped_column(ForeignKey("run_device.id"))
+    device_id: Mapped[int] = mapped_column(ForeignKey("run_device.id", ondelete="CASCADE"))
 
     device: Mapped[RunDevice] = orm.relationship(back_populates="instrument_runs")
     sample_metrics: Mapped[list["SampleRunMetrics"]] = orm.relationship(
@@ -1054,7 +1112,9 @@ class InstrumentRun(Base):
 class IlluminaSequencingRun(InstrumentRun):
     __tablename__ = "illumina_sequencing_run"
 
-    id: Mapped[int] = mapped_column(ForeignKey("instrument_run.id"), primary_key=True)
+    id: Mapped[int] = mapped_column(
+        ForeignKey("instrument_run.id", ondelete="CASCADE"), primary_key=True
+    )
     sequencer_type: Mapped[str | None] = mapped_column(
         types.Enum("hiseqga", "hiseqx", "novaseq", "novaseqx")
     )
@@ -1087,15 +1147,18 @@ class IlluminaSequencingRun(InstrumentRun):
         return data
 
 
-class PacBioSequencingRun(InstrumentRun):
+class PacbioSequencingRun(InstrumentRun):
     __tablename__ = "pacbio_sequencing_run"
 
-    id: Mapped[int] = mapped_column(ForeignKey("instrument_run.id"), primary_key=True)
+    id: Mapped[int] = mapped_column(
+        ForeignKey("instrument_run.id", ondelete="CASCADE"), primary_key=True
+    )
     well: Mapped[Str32]
     plate: Mapped[int]
+    run_name: Mapped[Str32]
     movie_name: Mapped[Str32]
-    started_at: Mapped[datetime | None]
-    completed_at: Mapped[datetime | None]
+    started_at: Mapped[datetime]
+    completed_at: Mapped[datetime]
     hifi_reads: Mapped[BigInt]
     hifi_yield: Mapped[BigInt]
     hifi_mean_read_length: Mapped[BigInt]
@@ -1116,9 +1179,20 @@ class PacBioSequencingRun(InstrumentRun):
     failed_reads: Mapped[BigInt]
     failed_yield: Mapped[BigInt]
     failed_mean_read_length: Mapped[BigInt]
+    barcoded_hifi_reads: Mapped[BigInt]
+    barcoded_hifi_reads_percentage: Mapped[Num_6_2]
+    barcoded_hifi_yield: Mapped[BigInt]
+    barcoded_hifi_yield_percentage: Mapped[Num_6_2]
+    barcoded_hifi_mean_read_length: Mapped[BigInt]
+    unbarcoded_hifi_reads: Mapped[BigInt]
+    unbarcoded_hifi_yield: Mapped[BigInt]
+    unbarcoded_hifi_mean_read_length: Mapped[BigInt]
 
     __mapper_args__ = {"polymorphic_identity": DeviceType.PACBIO}
 
+    def to_dict(self):
+        return to_dict(self)
+
 
 class SampleRunMetrics(Base):
     """Parent model for the different types of sample run metrics."""
@@ -1126,7 +1200,9 @@ class SampleRunMetrics(Base):
     __tablename__ = "sample_run_metrics"
     id: Mapped[PrimaryKeyInt]
     sample_id: Mapped[int] = mapped_column(ForeignKey("sample.id"))
-    instrument_run_id: Mapped[int] = mapped_column(ForeignKey("instrument_run.id"))
+    instrument_run_id: Mapped[int] = mapped_column(
+        ForeignKey("instrument_run.id", ondelete="CASCADE")
+    )
     type: Mapped[DeviceType]
 
     instrument_run: Mapped[InstrumentRun] = orm.relationship(back_populates="sample_metrics")
@@ -1142,7 +1218,9 @@ class IlluminaSampleSequencingMetrics(SampleRunMetrics):
 
     __tablename__ = "illumina_sample_sequencing_metrics"
 
-    id: Mapped[int] = mapped_column(ForeignKey("sample_run_metrics.id"), primary_key=True)
+    id: Mapped[int] = mapped_column(
+        ForeignKey("sample_run_metrics.id", ondelete="CASCADE"), primary_key=True
+    )
     flow_cell_lane: Mapped[int | None]
     total_reads_in_lane: Mapped[BigInt | None]
     base_passing_q30_percent: Mapped[Num_6_2 | None]
@@ -1153,19 +1231,36 @@ class IlluminaSampleSequencingMetrics(SampleRunMetrics):
     __mapper_args__ = {"polymorphic_identity": DeviceType.ILLUMINA}
 
 
-class PacBioSampleSequencingMetrics(SampleRunMetrics):
+class PacbioSampleSequencingMetrics(SampleRunMetrics):
     """Sequencing metrics for a sample sequenced on a PacBio instrument. The metrics are per sample, per cell."""
 
     __tablename__ = "pacbio_sample_run_metrics"
 
-    id: Mapped[int] = mapped_column(ForeignKey("sample_run_metrics.id"), primary_key=True)
+    id: Mapped[int] = mapped_column(
+        ForeignKey("sample_run_metrics.id", ondelete="CASCADE"), primary_key=True
+    )
     hifi_reads: Mapped[BigInt]
     hifi_yield: Mapped[BigInt]
     hifi_mean_read_length: Mapped[BigInt]
     hifi_median_read_quality: Mapped[Str32]
-    percent_reads_passing_q30: Mapped[Num_6_2]
-    failed_reads: Mapped[BigInt]
-    failed_yield: Mapped[BigInt]
-    failed_mean_read_length: Mapped[BigInt]
+    polymerase_mean_read_length: Mapped[BigInt]
 
     __mapper_args__ = {"polymorphic_identity": DeviceType.PACBIO}
+
+    def to_dict(self) -> dict:
+        """Represent as dictionary"""
+        return to_dict(self)
+
+
+class OrderTypeApplication(Base):
+    """Maps an order type to its allowed applications"""
+
+    __tablename__ = "order_type_application"
+
+    order_type: Mapped[OrderType] = mapped_column(sqlalchemy.Enum(OrderType), primary_key=True)
+    application_id: Mapped[int] = mapped_column(
+        ForeignKey("application.id", ondelete="CASCADE"), primary_key=True
+    )
+    application: Mapped[Application] = orm.relationship(
+        "Application", back_populates="order_type_applications"
+    )
